@@ -447,12 +447,6 @@ sub _external_request {
 sub _dummy_c {
     _debug2("create internal context");
     my($c) = _internal_request('/thruk/cgi-bin/remote.cgi');
-    #require Thruk;
-    #if(!$Thruk::thruk) {
-    #    Thruk->startup();
-    #}
-    #my $c = Thruk::Context->new($Thruk::thruk, {'PATH_INFO' => '/dummy-internal/'.__FILE__.':'.__LINE__});
-    #Thruk::Action::AddDefaults::begin($c);
     _debug2("create internal context done");
     return($c);
 }
@@ -842,11 +836,17 @@ sub get_submodule_help {
         $file = $module.'.pm';
     }
     $file =~ s/::/\//gmx;
+
+    my $sections = "DESCRIPTION|SYNOPSIS|OPTIONS|EXAMPLES";
+    if($ENV{'THRUK_BASH_COMP'}) {
+        $sections = "OPTIONS";
+    }
+
     my $output = "";
     open my $fh, ">", \$output or die $!;
     Pod::Usage::pod2usage({
             -verbose    => 99,
-            -sections   => "DESCRIPTION|SYNOPSIS|OPTIONS|EXAMPLES",
+            -sections   => $sections,
             -noperldoc  => 1,
             -input      => $INC{$file},
             -output     => $fh,
